#### lambda函数:匿名函数的使用

在 Python 编程中我们除了可以用def语句来定义函数之外，还可以使用lambda来定义。我们用def语句来定义函数时需要指定函数名字，而使用lambda来定义函数时则不需要。lambda函数是 Python 中一个非常独特的函数类型。

#### lambda函数

lambda函数又称匿名函数，匿名函数顾名思义就是没有名字的函数。可能我们现在还无法接受，函数没有名字怎么能行？但实际上是可以的。当我们在编程过程中只是临时使用某些函数，而且这些函数的逻辑功能也很简单时，就没有必要非给这些函数取个名字不可。

这就类似于电影里面都会有很多群众演员，他们每个人所占的戏份很少，只是起临时演出的作用，所以一般没有必要给临时演员起一个电影名字，统一称为群演就行。

匿名函数不需要return来返回值，lambda函数表达式本身的计算结果就是返回值。

<details><summary> lambda函数示例 </summary>
<hr>

例如，我们可以用lambda函数定义一个加法，计算两个整数相加：

```python
f = lambda x,y:x+y
print(f(1,2))
```

运算结果：
```python
3
```
x和y是函数的两个参数，:后面的表达式x+y表明函数的功能就是计算两个数的和。在这里我们并没有给函数取名字，而是直接将匿名函数赋给变量f。然后给f传入参数(1,2)，就相当于给匿名函数传入参数，得到返回结果3。
尽管 Python 算不上是一门纯函数式编程语言，但它本身提供了很多函数式编程的特性。像map、reduce、filter、sorted这些函数都支持函数作为参数，lambda函数也可以应用在函数式编程中。例如，现在有一个整数列表，要求按照列表中元素的绝对值从小到大排列。我们可以先采取普通def函数解决这个问题：

```python
# 给出一个包含正数和负数的列表
list1 = [2,3,-5,0,-4,-8,-1]
# 定义一个函数，返回输入值的绝对值
def f(x):
    return abs(x)
# 利用sorted函数对列表中的元素根据绝对值的大小升序排序
list2=sorted(list1, key=f)
# 输出新列表
print(list2)
```

我们也可以采取lambda函数更加简便地实现这个目标：

```python
# 给出一个包含正数和负数的列表
list1 = [2,3,-5,0,-4,-8,-1]
# 利用sorted函数对列表中的元素根据绝对值的大小升序排序
list2=sorted(list1, key=lambda x: abs(x))
# 输出新列表
print(list2)
```

由这个例子可以看出，lambda函数会使部分函数式编程更加简便与快捷。lambda函数能起到速写函数的作用，允许在使用的代码内嵌入一个函数的定义。在仅需要嵌入一小段可执行代码的情况下，就可以带来更简洁的代码结构。

</details>
