## 将函数作为返回值
我们除了可以将各种类型的值作为返回值外，也可以将函数作为返回值。

<details><summary> 将函数作为返回值举例 </summary>
<hr>

例如，我们要定义一个函数来求列表中数值元素的和，一般情况下我们是这样定义的：

```python
def plus(*args):
    s = 0
    for n in args:
        s = s + n
    return s
```

但是，如果我们不需要立刻求和，而是在后面的程序中，根据需求再计算，这种情况怎么办呢？这时我们定义的函数可以不返回求和的结果，而是返回计算求和的函数。所以我们还可以用如下方法定义函数：

```python
def lazy_plus(*args):
    def plus():
        s = 0
        for n in args:
            s = s + n
        return s
    return plus
```
当我们调用lazy_plus()时，返回的并不是求和结果，而是计算求和的函数：

```python
# 定义求和函数，返回的并不是求和结果，而是计算求和的函数
def lazy_plus(*args):
    def plus():
        s = 0
        for n in args:
            s = s + n
        return s
    return plus
# 调用lazy_plus()时，返回的并不是求和结果，而是求和函数
f = lazy_plus(1,2,3,4,5)
print(f)
```

输出结果：
`<function lazy_plus.<locals>.plus at 0x000001DAC97F9950>`

调用函数f时，才真正计算求和的结果：

```python
# 定义求和函数，返回的并不是求和结果，而是计算求和的函数
def lazy_plus(*args):
    def plus():
        s = 0
        for n in args:
            s = s + n
        return s
    return plus
# 调用函数f时，得到真正求和的结果
f = lazy_plus(1,2,3,4,5)
print(f())
```

输出结果：
`15`


</details>

在上述例子中，我们在函数lazy_plus中又定义了函数plus，而且内部函数plus是可以引用外部函数lazy_plus的参数和局部变量的。当函数lazy_plus返回函数plus时，相关参数和变量也将会保存在返回的函数中，这种方式也称为“闭包”（Closure）。

|| _我们将在介绍完函数的结构后对您的掌握进行实践题的测试。_ ||
